import { type ActionReturnType, actions } from 'astro:actions';
import { writable } from 'svelte/store';
import { actionErrorPopup } from '@util/action.ts';
import { addToWritableArray, deleteFromWritableArray, updateWritableArray } from '@util/state.ts';

// types
export type Teams = Exclude<ActionReturnType<typeof actions.team.teams>['data'], undefined>['teams'];
export type Team = Teams[0];

// state
export const teams = writable<Teams>([]);

// actions
export async function fetchTeams(name: string | null, username: string | null) {
  const { data, error } = await actions.team.teams({ name: name, username: username });
  if (error) {
    actionErrorPopup(error);
    return;
  }

  teams.set(data.teams);
}

export async function addTeam(team: Team) {
  const { data, error } = await actions.team.addTeam(team);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  addToWritableArray(teams, Object.assign(team, { id: data.id }));
}

export async function editTeam(team: Team) {
  const { error } = await actions.team.editTeam(team);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  updateWritableArray(teams, team, (t) => t.id == team.id);
}

export async function deleteTeam(team: Team) {
  const { error } = await actions.team.deleteTeam(team);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  deleteFromWritableArray(teams, (t) => t.id == team.id);
}
